summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/webcamwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/webcamwidget.h')
-rw-r--r--kopete/libkopete/webcamwidget.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/kopete/libkopete/webcamwidget.h b/kopete/libkopete/webcamwidget.h
index fdc60a6e..663c7723 100644
--- a/kopete/libkopete/webcamwidget.h
+++ b/kopete/libkopete/webcamwidget.h
@@ -28,16 +28,17 @@ namespace Kopete
/**
* A simple widget to display webcam frames.
*/
-class KOPETE_EXPORT WebcamWidget : public QWidget
+class KOPETE_EXPORT WebcamWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @brief WebcamWidget constructor.
* @param parent The parent widget of this widget
* @param name The name for this QObject
*/
- WebcamWidget( TQWidget* parent = 0, const char* name = 0 );
+ WebcamWidget( TQWidget* tqparent = 0, const char* name = 0 );
~WebcamWidget();
/**
@@ -56,8 +57,11 @@ public:
* @param text The text to be displayed
*/
void setText(const TQString& text);
+
protected slots:
void paintEvent( TQPaintEvent* event );
+
+protected:
TQPixmap mPixmap;
TQString mText;
};
@@ -28,16 +28,17 @@ namespace Kopete
/**
* @brief WebcamWidget constructor.
- * @param parent The parent widget of this widget
- * @param name The name for this QObject
+ * @param tqparent The tqparent widget of this widget
+ * @param name The name for this TQObject
*/